@@ -475,7 +475,7 @@
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-/* #undef HAVE_ERR_remove_thread_state */
+#define HAVE_ERR_remove_thread_state 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
@@ -601,8 +601,8 @@
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-/* #undef HAVE_EncryptAes128Ctr */
-/* #undef HAVE_EncryptAes128Gcm */
+#define HAVE_EncryptAes128Ctr 1
+#define HAVE_EncryptAes128Gcm 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -640,16 +640,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 22
+#define MYSQL_VERSION_PATCH 25
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.22"
+#define PACKAGE_STRING "MySQL Server 10.1.25"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.22"
-#define VERSION "10.1.22"
+#define PACKAGE_VERSION "10.1.25"
+#define VERSION "10.1.25"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
@@ -673,21 +673,4 @@
 #define __STDC_FORMAT_MACROS
 #endif
 
-/*
-  stat structure (from <sys/stat.h>) is conditionally defined
-  to have different layout and size depending on the defined macros.
-  The correct macro is defined in my_config.h, which means it MUST be
-  included first (or at least before <features.h> - so, practically,
-  before including any system headers).
-
-  Check the include order by looking at __GLIBC__ (defined in <features.h>)
-
-  But we cannot force all third-party clients/connectors to include
-  my_config.h first. So, their crashes are their responsibility,
-  we enable this check only for MariaDB sources (SAFE_MUTEX check).
-*/
-#if defined(__GLIBC__) && defined(SAFE_MUTEX)
-#error <my_config.h> MUST be included first!
-#endif
-
 #endif
